from instruction_ner.model import Model

__all__ = [
    "Model"
]
